@@ -27,6 +27,7 @@ namespace LongoMatch
 		public static string baseDirectory;
 		public static string homeDirectory;
 		public static string configDirectory;
+		public static bool fastTagging = false;
 		
 		public static string HomeDir() {
 			return homeDirectory;
@@ -74,9 +75,19 @@ namespace LongoMatch
 			return Path.Combine(baseDirectory, relativePath);
 		}
 		
+		public static bool FastTagging {
+			get {
+				return fastTagging;
+			}
+			set {
+				fastTagging = value;
+			}
+		}
+		
 		
 		/* Properties */
 		public static bool useGameUnits = false;
+		public static bool useUriCapture = false;
 
 	}
 }
