@@ -53,6 +53,7 @@ namespace LongoMatch.Gui
 		public event TagPlayHandler TagPlayEvent;
 		public event PlaysDeletedHandler PlaysDeletedEvent;
 		public event TimeNodeChangedHandler TimeNodeChanged;
+		public event PlayCategoryChangedHandler PlayCategoryChanged;
 		
 		/* Playlist */
 		public event RenderPlaylistHandler RenderPlaylistEvent;
@@ -259,6 +260,9 @@ namespace LongoMatch.Gui
 			/* Connect TimeNodeSelected events */
 			playsSelection.PlaySelected += OnTimeNodeSelected;
 			timeline.TimeNodeSelected += OnTimeNodeSelected;
+			
+			/* Connect PlayCategoryChanged events */
+			playsSelection.PlayCategoryChanged += EmitPlayCategoryChanged;
 
 			/* Connect playlist events */
 			playlist.PlayListNodeSelected += EmitPlayListNodeSelected;
@@ -290,7 +294,9 @@ namespace LongoMatch.Gui
 			guTimeline.UnitSelected += EmitUnitSelected;
 			guTimeline.UnitChanged += EmitUnitChanged;
 			
-			KeyPressEvent += (o, args) => (EmitKeyPressed(o, (int)args.Event.Key, (int)args.Event.Key));
+			playercapturer.Error += OnMultimediaError;
+			
+			KeyPressEvent += (o, args) => (EmitKeyPressed(o, (int)args.Event.Key, (int)args.Event.State));
  		}
 		
 		private void ConnectMenuSignals() {
@@ -390,7 +396,8 @@ namespace LongoMatch.Gui
 		}
 		
 		private void CloseCaptureProject() {
-			if(projectType == ProjectType.CaptureProject) {
+			if(projectType == ProjectType.CaptureProject ||
+			   projectType == ProjectType.URICaptureProject) {
 				playercapturer.Close();
 				playercapturer.Mode = PlayerCapturerBin.PlayerOperationMode.Player;
 				EmitSaveProject();
@@ -611,13 +618,6 @@ namespace LongoMatch.Gui
 		
 		#endregion
 
-		protected virtual void OnPlayerbin1Error(object o, string message)
-		{
-			MessagePopup.PopupMessage(this, MessageType.Info,
-			                          Catalog.GetString("The actual project will be closed due to an error in the media player:")+"\n" + message);
-			EmitCloseOpenedProject(true);
-		}
-
 		protected override bool OnKeyPressEvent(EventKey evnt)
 		{
 			Gdk.Key key = evnt.Key;
@@ -630,7 +630,8 @@ namespace LongoMatch.Gui
 				return ret;
 
 			if(projectType != ProjectType.CaptureProject &&
-			                projectType != ProjectType.FakeCaptureProject) {
+			   projectType != ProjectType.URICaptureProject &&
+			   projectType != ProjectType.FakeCaptureProject) {
 				switch(key) {
 				case Constants.SEEK_FORWARD:
 					if(modifier == Constants.STEP)
@@ -710,10 +711,10 @@ namespace LongoMatch.Gui
 			return true;
 		}
 
-		protected virtual void OnCapturerBinError(object o, string message)
+		protected virtual void OnMultimediaError(object o, string message)
 		{
-			MessagePopup.PopupMessage(this, MessageType.Info,
-				Catalog.GetString("An error occured in the video capturer and" +
+			MessagePopup.PopupMessage(this, MessageType.Error,
+				Catalog.GetString("The following error happened and" +
 				" the current project will be closed:")+"\n" + message);
 			EmitCloseOpenedProject(true);
 		}
@@ -741,6 +742,12 @@ namespace LongoMatch.Gui
 			if (PlaysDeletedEvent != null)
 				PlaysDeletedEvent(plays);
 		}
+		
+		protected virtual void EmitPlayCategoryChanged(Play play, Category cat)
+		{
+			if(PlayCategoryChanged != null)
+				PlayCategoryChanged(play, cat);
+		}
 
 		private void OnPlayListNodeAdded(Play play)
 		{
