@@ -81,6 +81,7 @@ namespace LongoMatch.Services
 			mainWindow.TimeNodeChanged += OnTimeNodeChanged;
 			mainWindow.PlaysDeletedEvent += OnPlaysDeleted;
 			mainWindow.PlaySelectedEvent += OnPlaySelected;
+			mainWindow.PlayCategoryChanged += OnPlayCategoryChanged;
 
 			/* Connect playlist events */
 			mainWindow.PlayListNodeSelectedEvent += (tn) => {selectedTimeNode = tn;};
@@ -111,7 +112,8 @@ namespace LongoMatch.Services
 			fStart = (start < new Time {MSeconds =0}) ? new Time {MSeconds = 0} : start;
 
 			if(projectType == ProjectType.FakeCaptureProject ||
-			   projectType == ProjectType.CaptureProject) {
+			   projectType == ProjectType.CaptureProject ||
+			   projectType == ProjectType.URICaptureProject) {
 				fStop = stop;
 			} else {
 				length = new Time {MSeconds = (int)player.StreamLength};
@@ -126,7 +128,7 @@ namespace LongoMatch.Services
 			Log.Debug(String.Format("New play created start:{0} stop:{1} category:{2}",
 									start, stop, category));
 			/* Get the current frame and get a thumbnail from it */
-			if(projectType == ProjectType.CaptureProject) {
+			if(projectType == ProjectType.CaptureProject || projectType == ProjectType.URICaptureProject) {
 				if(!capturer.Capturing) {
 					guiToolkit.InfoMessage(Catalog.GetString("You can't create a new play if the capturer "+
 						"is not recording."));
@@ -164,7 +166,8 @@ namespace LongoMatch.Services
 			Time pos;
 
 			if(projectType == ProjectType.FakeCaptureProject ||
-			   projectType == ProjectType.CaptureProject) {
+			   projectType == ProjectType.CaptureProject ||
+			   projectType == ProjectType.URICaptureProject) {
 				pos =  new Time { MSeconds = (int)capturer.CurrentTime};
 			} else {
 				pos = new Time {MSeconds = (int)player.CurrentTime};
@@ -272,5 +275,18 @@ namespace LongoMatch.Services
 		protected virtual void OnTagPlay(Play play) {
 			LaunchPlayTagger(play);
 		}
+		
+		protected virtual void OnPlayCategoryChanged(Play play, Category cat)
+		{
+			List<Play> plays = new List<Play>();
+			plays.Add(play);
+			OnPlaysDeleted(plays);
+			var newplay = openedProject.AddPlay(cat, play.Start, play.Stop, play.Miniature);
+			newplay.Name = play.Name;
+			newplay.Notes = play.Notes;
+			newplay.Drawings = play.Drawings;
+			mainWindow.AddPlay(newplay);
+			Core.DB.UpdateProject (openedProject);
+		}
 	}
 }
